
(_api_optical)=
# Optical Properties

## Class Objects

```{eval-rst}
.. autoclass:: sasktran2.optical.O3DBM

.. autoclass:: sasktran2.optical.NO2Vandaele

.. autoclass:: sasktran2.optical.HITRANUV

.. autoclass:: sasktran2.optical.HITRANTabulated

.. autoclass:: sasktran2.optical.database.OpticalDatabase

.. autoclass:: sasktran2.optical.database.OpticalDatabaseGenericAbsorber

.. autoclass:: sasktran2.optical.database.OpticalDatabaseGenericScatterer
```

## Special Modules

```{eval-rst}
.. automodule:: sasktran2.optical.rayleigh
```
